@@ -2,13 +2,13 @@ package LCFG::Build::Tools;    # -*-cperl-*-
 use strict;
 use warnings;
 
-# $Id: Tools.pm.in 12894 2010-07-12 15:44:11Z squinney@INF.ED.AC.UK $
+# $Id: Tools.pm.in 29146 2015-11-06 15:07:48Z squinney@INF.ED.AC.UK $
 # $Source: /var/cvs/dice/LCFG-Build-Tools/lib/LCFG/Build/Tools.pm.in,v $
-# $Revision: 12894 $
-# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Tools/LCFG_Build_Tools_0_5_1/lib/LCFG/Build/Tools.pm.in $
-# $Date: 2010-07-12 16:44:11 +0100 (Mon, 12 Jul 2010) $
+# $Revision: 29146 $
+# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Tools/LCFG_Build_Tools_0_6_0/lib/LCFG/Build/Tools.pm.in $
+# $Date: 2015-11-06 15:07:48 +0000 (Fri, 06 Nov 2015) $
 
-our $VERSION = '0.5.1';
+our $VERSION = '0.6.0';
 
 use Moose;
 
@@ -29,7 +29,7 @@ __END__
 
 =head1 VERSION
 
-This documentation refers to LCFG::Build::Tools version 0.5.1
+This documentation refers to LCFG::Build::Tools version 0.6.0
 
 =head1 DESCRIPTION
 
@@ -125,7 +125,9 @@ generating packages for MacOSX
 =head1 CONFIGURATION AND ENVIRONMENT
 
 Some of the tools use template files, by default it is assumed that
-the standard template directory is C</usr/share/lcfgbuild/templates>.
+the standard template directory is
+C</usr/local/share/lcfgbuild/templates> on MacOSX and
+C</usr/share/lcfgbuild/templates> on all other platforms.
 You can override this using the C<LCFG_BUILD_TMPLDIR> environment
 variable. If you have done a local (i.e. non-root) install of this
 module then this will almost certainly be necessary.
