@@ -2,13 +2,15 @@ package LCFG::Build::Utils;    # -*-cperl-*-
 use strict;
 use warnings;
 
-# $Id: Utils.pm.in 12955 2010-07-20 13:13:37Z squinney@INF.ED.AC.UK $
+# $Id: Utils.pm.in 29146 2015-11-06 15:07:48Z squinney@INF.ED.AC.UK $
 # $Source: /var/cvs/dice/LCFG-Build-Tools/lib/LCFG/Build/Utils.pm.in,v $
-# $Revision: 12955 $
-# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Tools/LCFG_Build_Tools_0_5_1/lib/LCFG/Build/Utils.pm.in $
-# $Date: 2010-07-20 14:13:37 +0100 (Tue, 20 Jul 2010) $
+# $Revision: 29146 $
+# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Tools/LCFG_Build_Tools_0_6_0/lib/LCFG/Build/Utils.pm.in $
+# $Date: 2015-11-06 15:07:48 +0000 (Fri, 06 Nov 2015) $
 
-our $VERSION = '0.5.1';
+our $VERSION = '0.6.0';
+
+use v5.10;
 
 use Cwd ();
 use File::Basename ();
@@ -20,37 +22,49 @@ use Module::Pluggable search_path => [ 'LCFG::Build::Utils' ];
 
 use constant NOT_FOUND => -1;
 
-{
-    my $datadir = exists $ENV{LCFG_BUILD_TMPLDIR}
-            ? $ENV{LCFG_BUILD_TMPLDIR}
-            : '/usr/share/lcfgbuild';
+sub datadirs {
 
-    sub datadir {
-        if ( defined $_[0] ) {
-            $datadir = $_[0];
-        }
-        return $datadir;
+  my @dirs;
+  if ( defined $ENV{LCFG_BUILD_TMPLDIR} && -d $ENV{LCFG_BUILD_TMPLDIR} ) {
+    push @dirs, $ENV{LCFG_BUILD_TMPLDIR};
+  }
+
+  for my $dir ( '/usr/local/share/lcfgbuild',
+                '/usr/share/lcfgbuild' ) {
+    if ( -d $dir ) {
+      push @dirs, $dir;
     }
+  }
+
+  return @dirs;
+
 }
 
-{    # Caching going on here, make variables only readable by this method.
+sub load_configs {
 
-    my ( $lcfgcfg, $mapping );
+  require YAML::Syck;
 
-    require YAML::Syck;
+  my @datadirs = datadirs();
 
-    sub load_configs {
-
-        my $datadir = datadir();
-
-        my $lcfg_file = File::Spec->catfile( $datadir, 'lcfg_config.yml' );
-        my $map_file  = File::Spec->catfile( $datadir, 'mapping_config.yml' );
-
-        $lcfgcfg ||= YAML::Syck::LoadFile($lcfg_file);
-        $mapping ||= YAML::Syck::LoadFile($map_file);
-
-        return ( $lcfgcfg, $mapping );
+  state $lcfgcfg = do {
+    my $lcfg_file;
+    for my $dir (@datadirs) {
+      $lcfg_file = File::Spec->catfile( $dir, 'lcfg_config.yml' );
+      last if -f $lcfg_file;
     }
+    YAML::Syck::LoadFile($lcfg_file);
+  };
+
+  state $mapping = do {
+    my $map_file;
+    for my $dir (@datadirs) {
+      $map_file = File::Spec->catfile( $dir, 'mapping_config.yml' );
+      last if -f $map_file;
+    }
+    YAML::Syck::LoadFile($map_file);
+  };
+
+  return ( $lcfgcfg, $mapping );
 }
 
 sub translate_macro {
@@ -258,11 +272,12 @@ sub generate_cmake {
 
     require Template;
 
-    my $datadir = datadir();
-    my $tmpldir = File::Spec->catdir( $datadir, 'templates' );
+    my @inc = grep { -d $_ }
+              map { File::Spec->catdir( $_, 'templates' ) }
+              datadirs();
 
     my $tt = Template->new(
-        {   INCLUDE_PATH => $tmpldir,
+        {   INCLUDE_PATH => \@inc,
             POST_CHOMP   => 1,
             PRE_CHOMP    => 1,
         }
@@ -358,7 +373,7 @@ __END__
 
 =head1 VERSION
 
-    This documentation refers to LCFG::Build::Utils version 0.5.1
+    This documentation refers to LCFG::Build::Utils version 0.6.0
 
 =head1 SYNOPSIS
 
@@ -478,10 +493,12 @@ be used. This returns the full path to the generated tar file.
 =head1 CONFIGURATION AND ENVIRONMENT
 
 Some of the routines use template files, by default it is assumed that
-the standard template directory is C</usr/share/lcfgbuild/templates>.
-You can override this using the LCFG_BUILD_TMPLDIR environment
-variable. If you have done a local (i.e. non-root) install of this
-module then this will almost certainly be necessary.
+the standard template directory is
+C</usr/local/share/lcfgbuild/templates> on MacOSX and
+C</usr/share/lcfgbuild/templates> on all other platforms.  You can
+override this using the LCFG_BUILD_TMPLDIR environment variable. If
+you have done a local (i.e. non-root) install of this module then this
+will almost certainly be necessary.
 
 =head1 DEPENDENCIES
 
